unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, OleCtrls, AP_PDF2TIFF_TLB, apconvert;

type
  TForm1 = class(TForm)
    m_ProgressBar: TProgressBar;
    btnDemo1: TButton;
    btnDemo2: TButton;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnDemo1Click(Sender: TObject);
    procedure btnDemo2Click(Sender: TObject);
  private
    { Private declarations }
    m_AxPdf2Tiff: TAxPdf2Tiff;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin
   //To create the com object.
   m_AxPdf2Tiff := TAxPdf2Tiff.Create(nil);
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
   //To free the com object.
   if( m_AxPdf2Tiff <> nil) then
       m_AxPdf2Tiff.Free;
end;

//Demo1 - To convert all pages of the pdf document.
procedure TForm1.btnDemo1Click(Sender: TObject);
var
   sFileName: String;
   nHandle,iPageNo,iPageCount: Integer;
   iStartTick,iEndTick: DWORD;
begin
   sFileName := 'sample.pdf';

   iStartTick := GetTickCount();

   //Open pdf document and creating a converter.
   nHandle := m_AxPdf2Tiff.apOpen(WideString(sFileName),'','');
   case nHandle of
     ERR_OVER_MAXTHREADS:
       begin ShowMessage('Over the limit amount of threads,please waiting!'); exit; end;
     ERR_FILE_UNEXIST:
       begin ShowMessage('Source pdf file unexist!'); exit; end;
     ERR_FILE_DAMAGED:
       begin ShowMessage('Source pdf file damaged!'); exit; end;
     ERR_FILE_RESTRICTED:
       begin ShowMessage('Source pdf file restricted!'); exit; end;
   end;

   //Setting proerties.
   m_AxPdf2Tiff.sOutDirectory := './demo1';
   m_AxPdf2Tiff.iMultiPages := 1;  //To generate multipages tiff.
   m_AxPdf2Tiff.iCompression := AP_TIFF_COMPRESSION_LZW;
   m_AxPdf2Tiff.iXDPI := 130;
   m_AxPdf2Tiff.iYDPI := 130;

   //To convert all pages of the pdf document.
   iPageCount := m_AxPdf2Tiff.apGetPageCount(nHandle);
   for iPageNo := 1 to iPageCount do
   begin
       m_AxPdf2Tiff.apConvertPage(nHandle,iPageNo);

       //Setting conversion's progress.
       m_ProgressBar.Position := Round((iPageNo)*1.0/iPageCount*100);
   end;

   //Close pdf document and destory the converter.
   m_AxPdf2Tiff.apClose(nHandle);

   //To count conversion's time(ms).
   iEndTick := GetTickCount();
   ShowMessage('Conversion successful,it passed '+IntToStr(iEndTick-iStartTick)+'ms!');
end;

//demo2 - To convert appointed pdf pages of the pdf document to memory stream.
procedure TForm1.btnDemo2Click(Sender: TObject);
var
   sFileName,sImgFile: String;
   nHandle,iPos,iPageCount: Integer;
   iStartTick,iEndTick: DWORD;
   m_Pages: array[0..5] of Longint;
   pImageStream: PByte;
   pFile: TFileStream;
begin
   sFileName := 'sample.pdf';
   m_Pages[0] := 1;   m_Pages[1] := 3;
   m_Pages[2] := 6;   m_Pages[3] := 8;
   m_Pages[4] := 9;   m_Pages[5] := 11;

   iStartTick := GetTickCount();

   //Open pdf document and creating a converter.
   nHandle := m_AxPdf2Tiff.apOpen(WideString(sFileName),'','');
   case nHandle of
     ERR_OVER_MAXTHREADS:
       begin ShowMessage('Over the limit amount of threads,please waiting!'); exit; end;
     ERR_FILE_UNEXIST:
       begin ShowMessage('Source pdf file unexist!'); exit; end;
     ERR_FILE_DAMAGED:
       begin ShowMessage('Source pdf file damaged!'); exit; end;
     ERR_FILE_RESTRICTED:
       begin ShowMessage('Source pdf file restricted!'); exit; end;
   end;

   //Setting proerties.
   m_AxPdf2Tiff.iCompression := AP_TIFF_COMPRESSION_LZW;
   m_AxPdf2Tiff.iXDPI := 110;
   m_AxPdf2Tiff.iYDPI := 110;
   m_AxPdf2Tiff.iXDimensions := 995;
   m_AxPdf2Tiff.iYDimensions := 1287;

   //To convert the appointed pages of the pdf file.
   iPageCount := 6;
   if not DirectoryExists('demo2') then mkdir('demo2');
   for iPos := 0 to iPageCount-1 do
   begin
       //You can save image stream to database, to file, or to others, etc.
       //The "pImageStream" is a pointer which point to the memory stream of an image.
       m_AxPdf2Tiff.apConvertPageToStream(nHandle,m_Pages[iPos]);
       pImageStream := PByte(m_AxPdf2Tiff.iStreamHandle);

       //Here,the stream is saved to file.
       if (pImageStream <> nil) and (m_AxPdf2Tiff.iStreamSize > 0) then
       begin
          sImgFile := PAnsiChar('demo2/myimg_'+IntToStr(m_Pages[iPos])+'.tif');
          pFile := TFileStream.Create(sImgFile,fmCreate or fmOpenWrite);
          pFile.WriteBuffer(pImageStream^,m_AxPdf2Tiff.iStreamSize);
          pFile.Free;
       end;

       //Setting conversion's progress.
       m_ProgressBar.Position := Round((iPos+1)*1.0/iPageCount*100);
   end;

   //Close pdf document and destory the converter.
   m_AxPdf2Tiff.apClose(nHandle);

   //To count conversion's time(ms).
   iEndTick := GetTickCount();
   ShowMessage('Conversion successful,it passed '+IntToStr(iEndTick-iStartTick)+'ms!');
end;

end.
